@@ -179,6 +179,11 @@ class Prompt(PromptBase):
 class UseCase(PromptBase):
     __tablename__ = 'ai_usecase' # 数据库中的表名，你可以改成你希望的名字
 
+    # __table_args__ = (
+    #     UniqueConstraint('prompt_id', 'use_case', name='_prompt_id_version_uc'),
+    #     # 'name' 参数是可选的，用于给数据库中的约束指定一个名称，方便管理和调试
+    # )
+
     # id (int, primary_key=True, autoincrement=True)
     # 你的属性表中 id 为 int, true (not null), true (primary key), 0 (length), ASC (key order), true (auto increment)
     id = Column(
@@ -206,6 +211,14 @@ class UseCase(PromptBase):
         comment="用例"
     )
 
+    timestamp = Column(
+        DateTime,
+        nullable=False,      # 不能为空
+        server_default=text('CURRENT_TIMESTAMP'),
+        onupdate=text('CURRENT_TIMESTAMP'),
+        comment="时间戳"
+    )
+
     output = Column(
         Text,               # TEXT 类型，适用于长文本
         nullable=False,     # 不能为空
@@ -220,6 +233,12 @@ class UseCase(PromptBase):
         comment="理想结果"      # 列注释
     )
 
+    faired_time = Column(
+        Integer,
+        nullable=False,     # 不能为空
+        comment="失败次数"
+    )
+
     is_deleted = Column(Boolean, default=False, server_default=text('0')) 
 
     # 定义 __repr__ 方法以便打印对象时有清晰的表示
