@@ -159,18 +159,32 @@ class AsyncIntel():
                                     pool_pre_ping=True,  # 使用前检查连接活性
                                     pool_timeout=30      # 等待连接池中连接的最长时间（秒）
                                            )
-        
 
         if model_name in ["gemini-2.5-flash-preview-05-20-nothinking",]:
             self.llm = BianXieAdapter(model_name = model_name)
-        elif model_name in ["doubao-1-5-pro-256k-250115",]:
+        elif model_name in ["doubao-1-5-pro-256k-250115","doubao-1-5-pro-32k-250115"]:
             self.llm = ArkAdapter(model_name = model_name)
         else:
-            print('Use BianXieAdapter')
-            self.llm = BianXieAdapter()
+            raise Exception("error llm name")
             
-    async def create_database(self):
+    async def create_specific_database(self):
+        tables_to_create_names = ["ai_prompts","ai_usecase"]
         async with self.engine.begin() as conn:
+            # 从 metadata 中获取对应的 Table 对象
+            specific_database_objects = []
+            for table_name in tables_to_create_names:
+                if table_name in PromptBase.metadata.tables:
+                    specific_database_objects.append(PromptBase.metadata.tables[table_name])
+                else:
+                    print(f"Warning: Table '{table_name}' not found in metadata.")
+
+            if specific_database_objects:
+                await conn.run_sync(PromptBase.metadata.create_all, tables=specific_database_objects)
+            else:
+                print("No specific tables to create.")
+
+    async def create_database(self,engine):
+        async with engine.begin() as conn:
             await conn.run_sync(PromptBase.metadata.create_all)
             
     async def _get_latest_prompt_version(self,target_prompt_id,session):
@@ -218,9 +232,7 @@ class AsyncIntel():
 
     async def sync_prompt_data_to_database(self,database_url:str):
         target_engine = create_async_engine(database_url, echo=False)
-        async with target_engine.begin() as conn:
-            await conn.run_sync(PromptBase.metadata.create_all)
-            
+        await self.create_database(target_engine) 
         async with create_async_session(self.engine) as source_session:
             async with create_async_session(target_engine) as target_session:
             
@@ -241,6 +253,7 @@ class AsyncIntel():
                     )
                     records_to_sync = source_results.scalars().all()
                     if not records_to_sync:
+                        print("没有更多记录了")
                         break # 没有更多记录了
 
                     #2 max_timestamp_in_batch = datetime(1970, 1, 1) # 初始化为最早时间
@@ -899,6 +912,7 @@ class AsyncIntel():
                     prompt_id: str,
                     ExtraFormats: list[object] = [],
                     version: str = None,
+                    MIN_SUCCESS_RATE = 80.0
                     ):
         
         async with create_async_session(self.engine) as session:
@@ -961,22 +975,10 @@ class AsyncIntel():
                     bad_case.append(i)
 
             success_rate = (successful_assertions / total_assertions) * 100
-            print(f"\n--- Aggregated Results ---")
-            print(f"Total test cases: {total_assertions}")
-            print(f"Successful cases: {successful_assertions}")
-            print(f"Success Rate: {success_rate:.2f}%")
-
-            # if success_rate >= MIN_SUCCESS_RATE:
-            #     return "通过", json.dumps(result_cases,ensure_ascii=False)
-            # else:
-            #     return "未通过",json.dumps(result_cases,ensure_ascii=False)
-
-            print(bad_case)
-
-            
-            # return results
-
-
 
+            if success_rate >= MIN_SUCCESS_RATE:
+                return "通过", success_rate, total_assertions, json.dumps(bad_case,ensure_ascii=False),
+            else:
+                return "未通过",success_rate, total_assertions, json.dumps(bad_case,ensure_ascii=False),
 
 # 整体测试d, 测试未通过d, 大模型调整再测试, 依旧不通过, 大模型裂变, 仍不通过, 互换人力
