@@ -1,13 +1,15 @@
 
 
 from fastapi import APIRouter
-from pro_craft import Intel
-from pro_craft.utils import create_session
+from pro_craft import Intel,AsyncIntel
+from pro_craft.utils import create_async_session
 
 def create_router(database_url: str,
                   slave_database_url: str,
-                  model_name: str):
+                  model_name: str,
+                  logger = None):
     """
+    # TODO 整理改为异步
     创建一个包含 ProCraft 路由的 FastAPI APIRouter 实例。
 
     Args:
@@ -20,18 +22,20 @@ def create_router(database_url: str,
         APIRouter: 配置好的 FastAPI APIRouter 实例。
     """
 
-    intels = Intel(
+    intels = AsyncIntel(
         database_url=database_url,
-        model_name=model_name
+        model_name=model_name,
+        logger=logger
         )
 
     router = APIRouter(
         tags=["prompt"] # 这里使用 Depends 确保每次请求都验证
     )
 
-    @router.get("/push_order")
+    @router.get("/push_order",
+                description="可选 train,inference,summary,finetune,patch",)
     async def push_order(demand: str, prompt_id: str, action_type: str = "train"):
-        result = intels.push_action_order(
+        result = await intels.push_action_order(
             demand=demand,
             prompt_id=prompt_id,
             action_type=action_type
@@ -40,8 +44,8 @@ def create_router(database_url: str,
 
     @router.get("/get_latest_prompt")
     async def get_latest_prompt(prompt_id: str):
-        with create_session(intels.engine) as session:
-            result = intels.get_prompts_from_sql(
+        async with create_async_session(intels.engine) as session:
+            result = await intels.get_prompts_from_sql(
                 prompt_id=prompt_id,
                 session=session
             )
@@ -49,7 +53,28 @@ def create_router(database_url: str,
 
     @router.get("/sync_database")
     async def sync_database():
-        result = intels.sync_prompt_data_to_database(slave_database_url)
+        result = await intels.sync_prompt_data_to_database(slave_database_url)
         return {"message": "success","result":result}
     
+
+    @router.get("/roll_back")
+    async def roll_back(prompt_id:str,version:str):
+        async with create_async_session(intels.engine) as session:
+            result = await intels.get_prompts_from_sql(
+                prompt_id=prompt_id,
+                version = version,
+                session=session
+            )
+            assert result.version == version
+            await intels.save_prompt_increment_version(
+                            prompt_id = prompt_id,
+                            new_prompt = result.prompt,
+                            use_case = result.use_case,
+                            action_type = "inference",
+                            demand = "",
+                            score = 61,
+                            session = session)
+        return {"message": "success"}
+    
     return router
+
